/*
 * Copyright 09/20/96 Sun Microsystems, Inc.  All Rights Reserved.
 */

/*
 * t_lock.h (interposed) interface for annotating source for use with lock_lint
 *
 * This file gets included instead of the "real" sys/t_lock.h when
 * compiling for lock_lint.  When using the -Zll flag the compiler
 * includes the real sys/t_lock.h.  Then it undefines the various macros
 * so that MUTEX_HELD doesn't get translated to mutex_owned, etc.  Then
 * it defines mutex_owned to MUTEX_HELD, etc.  The reason for doing this
 * is that we want the compiler (when using -Zll) to just know about one
 * set of interfaces, regardless of whether the code being compiled is
 * user code or kernel code.  The macros exist in both, but the
 * functions do not.  This file causes all such kernel function
 * invocations to be converted to the corresponding macro invocations so
 * that the compiler will recognize them.
 *
 * Since MUTEX_HELD, etc. are no longer macros, we must provide
 * declarations for them.
 *
 * Macros NO_LOCKS_HELD and NO_COMPETING_THREADS are redefined so that
 * we can recognize assertions involving them.
 */

#ifndef _SYS_T_LOCK_H

/*
 * Do NOT define _SYS_T_LOCK_H here, we do not want to supress the
 * the expansion of t_lock.h by the private undocumented #pragma reinclude.
 * The private undocumented #pragma reinclude will include the next (real)
 * version of t_lock.h in the include path, this should be in /usr/sys.
 */

#pragma ident "@(#)t_lock.h 1.2 96/09/20 SMI"

#pragma reinclude

#if defined(_KERNEL)

#undef MUTEX_HELD
#undef RW_READ_HELD
#undef RW_WRITE_HELD
#undef RW_LOCK_HELD

#define mutex_owned     MUTEX_HELD

#ifdef __cplusplus
extern "C" {
#endif

extern int MUTEX_HELD(kmutex_t *);
extern int RW_READ_HELD(krwlock_t *);
extern int RW_WRITE_HELD(krwlock_t *);
extern int RW_LOCK_HELD(krwlock_t *);

#undef  NO_LOCKS_HELD
#define NO_LOCKS_HELD \
	   __ASSERT__NO_LOCKS_HELD()
extern int __ASSERT__NO_LOCKS_HELD();

#undef  NO_COMPETING_THREADS
#define NO_COMPETING_THREADS \
	   __ASSERT__NO_COMPETING_THREADS()
extern int __ASSERT__NO_COMPETING_THREADS();

#ifdef __cplusplus
}
#endif
#endif  /* _KERNEL */
#endif  /* _SYS_T_LOCK_H */
